var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { ContentChildren, Component, ElementRef, EventEmitter, forwardRef, Input, Output, NgZone, Renderer } from '@angular/core';
import { Ion } from '../ion';
import { Config } from '../../config/config';
import { Platform } from '../../platform/platform';
import { RootNode } from '../../navigation/root-node';
var QUERY = {
    xs: '(min-width: 0px)',
    sm: '(min-width: 576px)',
    md: '(min-width: 768px)',
    lg: '(min-width: 992px)',
    xl: '(min-width: 1200px)',
    never: ''
};
/**
 * @name SplitPane
 */
export var SplitPane = (function (_super) {
    __extends(SplitPane, _super);
    function SplitPane(_zone, _plt, config, elementRef, renderer) {
        _super.call(this, config, elementRef, renderer, 'split-pane');
        this._zone = _zone;
        this._plt = _plt;
        this._visible = false;
        this._init = false;
        this._mediaQuery = QUERY['md'];
        this.ionChange = new EventEmitter();
    }
    SplitPane.prototype.updateChildren = function () {
        var _this = this;
        this.mainContent = null;
        this.sideContent = null;
        this.children.forEach(function (child) {
            if (child !== _this) {
                var isSide = child._isSideContent();
                _this.setPaneCSSClass(child.getElementRef(), isSide);
                if (child.enabled) {
                    if (isSide) {
                        if (_this.sideContent) {
                            console.error('split pane: side content was already set');
                        }
                        _this.sideContent = child;
                    }
                    else {
                        if (_this.mainContent) {
                            console.error('split pane: main content was already set');
                        }
                        _this.mainContent = child;
                    }
                }
                child._setIsPane(_this._visible);
            }
        });
        if (!this.mainContent) {
            console.error('split pane: one of the elements needs the "main" attribute');
        }
        if (this.mainContent === this.sideContent) {
            console.error('split pane: main and side content are the same');
        }
    };
    Object.defineProperty(SplitPane.prototype, "when", {
        get: function () {
            return this._mediaQuery;
        },
        set: function (query) {
            if (typeof query === 'boolean') {
                this._mediaQuery = query;
            }
            else {
                var defaultQuery = QUERY[query];
                this._mediaQuery = (defaultQuery)
                    ? defaultQuery
                    : query;
            }
            this._update();
        },
        enumerable: true,
        configurable: true
    });
    SplitPane.prototype.ngAfterViewInit = function () {
        this._init = true;
        this._update();
    };
    SplitPane.prototype._update = function () {
        var _this = this;
        if (!this._init) {
            return;
        }
        // Unlisten
        this._rmListener && this._rmListener();
        this._rmListener = null;
        var query = this._mediaQuery;
        if (typeof query === 'boolean') {
            this.setVisible(query);
            return;
        }
        if (query && query.length > 0) {
            // Listen
            var callback_1 = function (query) { return _this.setVisible(query.matches); };
            var mediaList_1 = this._plt.win().matchMedia(query);
            mediaList_1.addListener(callback_1);
            this.setVisible(mediaList_1.matches);
            this._rmListener = function () {
                mediaList_1.removeListener(callback_1);
            };
        }
        else {
            this.setVisible(false);
        }
    };
    SplitPane.prototype.setVisible = function (visible) {
        var _this = this;
        if (this._visible === visible) {
            return;
        }
        this._visible = visible;
        this.setElementClass('split-pane-visible', visible);
        this.updateChildren();
        this._zone.run(function () {
            _this.ionChange.emit(_this);
        });
    };
    SplitPane.prototype.isVisible = function () {
        return this._visible;
    };
    SplitPane.prototype.setElementClass = function (className, add) {
        this._renderer.setElementClass(this._elementRef.nativeElement, className, add);
    };
    SplitPane.prototype.setPaneCSSClass = function (elementRef, isSide) {
        var ele = elementRef.nativeElement;
        this._renderer.setElementClass(ele, 'split-pane-side', isSide);
        this._renderer.setElementClass(ele, 'split-pane-main', !isSide);
    };
    SplitPane.prototype.ngOnDestroy = function () {
        (void 0) /* assert */;
        this._rmListener && this._rmListener();
        this._rmListener = null;
    };
    SplitPane.prototype._setIsPane = function (isPane) {
        // Conforms to RootNode abstract class
    };
    SplitPane.prototype._isSideContent = function () {
        return false;
    };
    Object.defineProperty(SplitPane.prototype, "enabled", {
        get: function () {
            return true;
        },
        enumerable: true,
        configurable: true
    });
    SplitPane.decorators = [
        { type: Component, args: [{
                    selector: 'ion-split-pane',
                    template: '<ng-content></ng-content>',
                    providers: [{ provide: RootNode, useExisting: forwardRef(function () { return SplitPane; }) }]
                },] },
    ];
    /** @nocollapse */
    SplitPane.ctorParameters = [
        { type: NgZone, },
        { type: Platform, },
        { type: Config, },
        { type: ElementRef, },
        { type: Renderer, },
    ];
    SplitPane.propDecorators = {
        'children': [{ type: ContentChildren, args: [RootNode, { descendants: false },] },],
        'when': [{ type: Input },],
        'ionChange': [{ type: Output },],
    };
    return SplitPane;
}(Ion));
//# sourceMappingURL=split-pane.js.map